..  This file is part of Invenio
    Copyright (C) 2014, 2015 CERN.

    Invenio is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

:orphan:

=========
 Aliases
=========

Sometimes *Sphinx* is confused so we have to help him a bit.


Jinja2
======

.. py:class:: jinja2.bccache.MemcachedBytecodeCache

    :py:class:`jinja:jinja2.MemcachedBytecodeCache`

Flask
=====

.. py:class:: flask.templating.DispatchingJinjaLoader

    A loader that looks for templates in the application and all the blueprint
    folders.

Flask-Assets
============

.. py:class:: flask_assets.FlaskResolver

    A subclass of the webassets resolver.

.. py:class:: flask_assets.ManageAssets


    A Flask-Script command for managing assets, see:
    :ref:`webassets:script-commands`

Flask-Login
===========

.. py:class:: flask_login.UserMixin

   Sorry not valid intersphinx were found for: ``flask_login.UserMixin``.


Flask-Script
============

.. py:class:: flask_script.commands.Command

    :py:class:`flaskscript:flask_script.Command`

Webassets
=========

.. py:class:: webassets.bundle.Bundle

    A webasset :ref:`Bundle <webassets:bundles>` that combines resources such a
    JavaScript or CSS stylesheets.

.. py:class:: webassets.filter.ExternalTool

    Subclass that helps creating filters that need to run an external
    program.
